import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;

import javax.swing.BoxLayout;

import jpos.*;
import jpos.events.*;

public class CashdrawerSample{
	public static void main(String args[]){		
		CashdrawerEventFrame ef = new CashdrawerEventFrame();
		ef.setVisible(true);
	}
}

class CashdrawerEventFrame extends Frame implements ActionListener, ItemListener, StatusUpdateListener{
	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;
	Button openService = null;
	Button openCashdrawer = null;
	Button closeService = null;
	Button exitProgram = null;
	Checkbox cashdrawerOpen = null;
	Checkbox offline = null;
	Checkbox powerCheck = null;
	Checkbox freezeEvent = null;
	CashDrawer cd = null;	
	
	CashdrawerEventFrame(){
		int width = 300;
		int height = 180;
		
		Panel topPan = new Panel();
		this.add(topPan);
		
		GridLayout gl2 = new GridLayout(1, 2, 5, 5);
		topPan.setLayout(gl2);
		
		cashdrawerOpen = new Checkbox("CashdrawerOpen");
		offline = new Checkbox("Offline");
		Panel leftPan = new Panel();
		leftPan.setLayout(new BoxLayout(leftPan,BoxLayout.Y_AXIS));
		leftPan.add(cashdrawerOpen);
		leftPan.add(offline);
		cashdrawerOpen.setEnabled(false);
		offline.setEnabled(false);
		topPan.add(leftPan);
		
		openService = new Button("Open Service");
		openCashdrawer = new Button("Open Cashdrawer");
		closeService = new Button("Close Service");
		exitProgram = new Button("Exit Program");
		powerCheck = new Checkbox("CheckPower");		
		freezeEvent = new Checkbox("FreezeEvent");
		Panel rightPan = new Panel();
		rightPan.setLayout(new BoxLayout(rightPan,BoxLayout.Y_AXIS));
		rightPan.add(openService);
		rightPan.add(powerCheck);
		rightPan.add(freezeEvent);
		rightPan.add(openCashdrawer);
		rightPan.add(closeService);
		rightPan.add(exitProgram);
		openService.addActionListener(this);
		openCashdrawer.addActionListener(this);
		closeService.addActionListener(this);
		exitProgram.addActionListener(this);
		powerCheck.addItemListener(this);
		freezeEvent.addItemListener(this);
		closeService.setEnabled(false);
		powerCheck.setEnabled(false);
		freezeEvent.setEnabled(false);
		topPan.add(rightPan);		
		
		this.setTitle("CashdrawerEvent Sample");
		Dimension dimen = Toolkit.getDefaultToolkit().getScreenSize();		
		this.setSize(width, height);
		this.setLocation(dimen.width/2-width/2, dimen.height/2 - height/2);
		
		cd = new CashDrawer();
		
	}

	public void actionPerformed(ActionEvent e) {
		if(e.getSource() == openService){
			try {
				cd.open("defaultCashdrawer");
				cd.claim(0);
				cd.addStatusUpdateListener(this);
				cd.setDeviceEnabled(true);
			} catch (JposException e1) {
				e1.printStackTrace();
				System.exit(0);
			}
			
			openService.setEnabled(false);
			closeService.setEnabled(true);
			powerCheck.setEnabled(true);
			freezeEvent.setEnabled(true);
		}
		else if(e.getSource() == closeService){
			try {
				cd.setDeviceEnabled(false);
				cd.release();
				cd.close();
			} catch (JposException jposEvent) {
				jposEvent.printStackTrace();
				System.exit(0);
			}
			openService.setEnabled(true);
			closeService.setEnabled(false);
			powerCheck.setEnabled(false);
			freezeEvent.setEnabled(false);
		}		
		else if(e.getSource() == openCashdrawer){
			try {
				cd.openDrawer();
			} catch (JposException jposEvent) {
				jposEvent.printStackTrace();
			}
		}
		else if(e.getSource() == exitProgram)
			System.exit(0);
	}

	public void itemStateChanged(ItemEvent arg0) {
		if(arg0.getItem() == "CheckPower"){
			try {
				Checkbox cb = (Checkbox)arg0.getSource();
				cd.setDeviceEnabled(false);
				if(cb.getState())
					cd.setPowerNotify(JposConst.JPOS_PN_ENABLED);
				else
					cd.setPowerNotify(JposConst.JPOS_PN_DISABLED);
				cd.setDeviceEnabled(true);
			} catch (JposException e) {
				e.printStackTrace();
			}		
		}	
		else if(arg0.getItem() == "FreezeEvent"){
			try {
				Checkbox cb = (Checkbox)arg0.getSource();
				if(cb.getState())
					cd.setFreezeEvents(true);
				else
					cd.setFreezeEvents(false);
			} catch (JposException e) {
				e.printStackTrace();
			}		
		}
	}

	public void statusUpdateOccurred(StatusUpdateEvent e) {
		switch (e.getStatus()) {
		case CashDrawerConst.CASH_SUE_DRAWEROPEN:
			cashdrawerOpen.setState(true);
			break;
		case CashDrawerConst.CASH_SUE_DRAWERCLOSED:
			cashdrawerOpen.setState(false);
			break;
		case JposConst.JPOS_SUE_POWER_OFF_OFFLINE:
			offline.setState(true);
			break;
		case JposConst.JPOS_SUE_POWER_ONLINE:
			offline.setState(false);
			break;
		}
	}
}
