import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import jpos.*;

public class DirectIOSample{
	public static void main(String args[]){		
		DirectIOFrame pnf;
		pnf = new DirectIOFrame();
		pnf.setVisible(true);
	}
}

class DirectIOFrame extends Frame implements ActionListener{
	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;
	Button interCharButton = null;
	Button alarmButton = null;
	Button closeButton = null;
	POSPrinter ptr = null;
	
	private enum InternationalCharList { 
		USA(0), France(1), Germany(2), UnitedKingdom(3), DenmarkI(4), Sweden(5), Italy(6),
	    SpainI(7), Japan(8), Norway(9), DenmarkII(10), SpainII(11), LatinAmerica(12), Korea(13);
		
		private final int value;
		private InternationalCharList(int value) { this.value = value; }
		public int getValue() { return value; }
	}
	
	DirectIOFrame(){
		int width = 180;
		int height = 130;
		
		FlowLayout fl = new FlowLayout(FlowLayout.CENTER);
		this.setLayout(fl);
		interCharButton = new Button("Set International char");
		interCharButton.addActionListener(this);
		alarmButton = new Button("Play Alarm (G30 Only)");
		alarmButton.addActionListener(this);
		closeButton = new Button("Close");
		closeButton.addActionListener(this);
		this.add(interCharButton);
		this.add(alarmButton);
		this.add(closeButton);
		this.setTitle("DirectIO Sample");
		Dimension dimen = Toolkit.getDefaultToolkit().getScreenSize();		
		this.setSize(width, height);
		this.setLocation(dimen.width/2-width/2, dimen.height/2 - height/2);		

		ptr = new POSPrinter();
		try {
			ptr.open("defaultPrinter");
			ptr.claim(0);
			ptr.setDeviceEnabled(true);
		} catch (JposException e) {
			e.printStackTrace();
			System.exit(0);
		}
	}

	public void actionPerformed(ActionEvent e) {
		if(e.getSource() == interCharButton){
			final int PTR_DI_INTERNATIONAL_CHAR = 1;
			try	{
				for(InternationalCharList interChar : InternationalCharList.values())
				{
					int[] data = { interChar.getValue() };
					ptr.directIO(PTR_DI_INTERNATIONAL_CHAR, data, null);
					ptr.printNormal(POSPrinterConst.PTR_S_RECEIPT, "Set " + interChar.name() + "\n");
					ptr.printNormal(POSPrinterConst.PTR_S_RECEIPT, "|4C# $ % & @ [ \\ ] ^ ` { | } ~ \n\n\n");
				}
				if(ptr.getCapRecPapercut() == true)
					ptr.printNormal(POSPrinterConst.PTR_S_RECEIPT, "|fP");
			} catch (JposException jposEvent) {
				jposEvent.printStackTrace();
			}
		}
		
		//G30 Only
		else if(e.getSource() == alarmButton){
			try {
				final int PTR_DI_G30_ALARM = 7;
				int[] data = { 3 }; //Alarm play count
				ptr.directIO(PTR_DI_G30_ALARM, data, null);
			} catch (JposException jposEvent) {
				jposEvent.printStackTrace();
			}
		}
		
		else if(e.getSource() == closeButton)
			try {
				ptr.setDeviceEnabled(false);
				ptr.release();
				ptr.close();
				System.exit(0);
			} catch (JposException e1) {
				e1.printStackTrace();
				System.exit(0);				
			}			
	}
}
