import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;

import javax.swing.BoxLayout;

import jpos.*;
import jpos.events.*;

public class POSPrinterEventsSample{
	public static void main(String args[]){		
		POSPrinterEventFrame ef = new POSPrinterEventFrame();
		ef.setVisible(true);
	}
}

class POSPrinterEventFrame extends Frame implements ActionListener, ItemListener, StatusUpdateListener, OutputCompleteListener, ErrorListener{
	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;
	Button openService = null;
	Button closeService = null;
	Button exitProgram = null;
	Button outputcomplete = null;
	Label status = null;
	Checkbox coverOpen = null;
	Checkbox paperEmpty = null;
	Checkbox offline = null;
	Checkbox paperNearEmpty = null;
	Checkbox powerCheck = null;
	Checkbox freezeEvent = null;
	POSPrinter ptr = null;
	
	POSPrinterEventFrame(){
		int width = 300;
		int height = 320;
		
		GridLayout gl = new GridLayout(2,1,1,1);
		this.setLayout(gl);
		Panel topPan = new Panel();
		status = new Label();
		this.add(topPan);
		this.add(status);
		
		GridLayout gl2 = new GridLayout(1, 2, 5, 5);
		topPan.setLayout(gl2);
		
		coverOpen = new Checkbox("CoveOpen");
		paperEmpty = new Checkbox("PaperEmpty");
		offline = new Checkbox("Offline");
		paperNearEmpty = new Checkbox("PaperNearEmpty");
		Panel leftPan = new Panel();
		leftPan.setLayout(new BoxLayout(leftPan,BoxLayout.Y_AXIS));
		leftPan.add(coverOpen);
		leftPan.add(paperEmpty);
		leftPan.add(offline);
		leftPan.add(paperNearEmpty);
		coverOpen.setEnabled(false);
		paperEmpty.setEnabled(false);
		offline.setEnabled(false);
		paperNearEmpty.setEnabled(false);
		topPan.add(leftPan);
		
		openService = new Button("Open Service");
		closeService = new Button("Close Service");
		exitProgram = new Button("Exit Program");
		outputcomplete = new Button("OutputCompleteEvent");				
		powerCheck = new Checkbox("CheckPower");
		freezeEvent = new Checkbox("FreezeEvent");
		Panel rightPan = new Panel();
		rightPan.setLayout(new BoxLayout(rightPan,BoxLayout.Y_AXIS));
		rightPan.add(openService);
		rightPan.add(powerCheck);
		rightPan.add(freezeEvent);
		rightPan.add(outputcomplete);
		rightPan.add(closeService);
		rightPan.add(exitProgram);
		openService.addActionListener(this);
		closeService.addActionListener(this);
		exitProgram.addActionListener(this);
		outputcomplete.addActionListener(this);
		powerCheck.addItemListener(this);
		freezeEvent.addItemListener(this);
		closeService.setEnabled(false);
		outputcomplete.setEnabled(false);
		powerCheck.setEnabled(false);
		freezeEvent.setEnabled(false);
		topPan.add(rightPan);		
		
		this.setTitle("PrintEvent Sample");
		Dimension dimen = Toolkit.getDefaultToolkit().getScreenSize();		
		this.setSize(width, height);
		this.setLocation(dimen.width/2-width/2, dimen.height/2 - height/2);		
		
		ptr = new POSPrinter();
	}

	public void actionPerformed(ActionEvent e) {
		if(e.getSource() == openService){
			
			
			try {
				ptr.open("defaultPrinter");
				ptr.claim(0);
				ptr.setDeviceEnabled(true);
				ptr.addStatusUpdateListener(this);
				ptr.addOutputCompleteListener(this);
				ptr.addErrorListener(this);
			} catch (JposException jposEvent) {
				jposEvent.printStackTrace();
				System.exit(0);
			}
			openService.setEnabled(false);
			closeService.setEnabled(true);
			powerCheck.setEnabled(true);
			freezeEvent.setEnabled(true);
			outputcomplete.setEnabled(true);
		}
		else if(e.getSource() == closeService){
			try {
				ptr.setDeviceEnabled(false);
				ptr.release();
				ptr.close();
			} catch (JposException jposEvent) {
				jposEvent.printStackTrace();
				System.exit(0);
			}
			openService.setEnabled(true);
			closeService.setEnabled(false);
			powerCheck.setEnabled(false);
			freezeEvent.setEnabled(false);
			outputcomplete.setEnabled(false);
		}
		else if(e.getSource() == outputcomplete){
			try {
				ptr.setAsyncMode(true);
				ptr.printNormal(POSPrinterConst.PTR_S_RECEIPT, "Sample String\r\n");
			} catch (JposException jposEvent) {
				jposEvent.printStackTrace();
			}
		}
		else if(e.getSource() == exitProgram)
			System.exit(0);
	}

	public void itemStateChanged(ItemEvent arg0) {
		if(arg0.getItem() == "CheckPower"){
			try {
				Checkbox cb = (Checkbox)arg0.getSource();
				ptr.setDeviceEnabled(false);
				if(cb.getState())
					ptr.setPowerNotify(JposConst.JPOS_PN_ENABLED);
				else
					ptr.setPowerNotify(JposConst.JPOS_PN_DISABLED);
				ptr.setDeviceEnabled(true);
			} catch (JposException e) {
				e.printStackTrace();
			}		
		}			
		else if(arg0.getItem() == "FreezeEvent"){
			try {
				Checkbox cb = (Checkbox)arg0.getSource();
				if(cb.getState())
					ptr.setFreezeEvents(true);
				else
					ptr.setFreezeEvents(false);
			} catch (JposException e) {
				e.printStackTrace();
			}		
		}
	}

	public void statusUpdateOccurred(StatusUpdateEvent e) {
		switch (e.getStatus()) {
		case POSPrinterConst.PTR_SUE_COVER_OK:
			coverOpen.setState(false);
			break;
		case POSPrinterConst.PTR_SUE_COVER_OPEN:
			coverOpen.setState(true);
			break;
		case POSPrinterConst.PTR_SUE_REC_EMPTY:
			paperEmpty.setState(true);
			break;
		case POSPrinterConst.PTR_SUE_REC_NEAREMPTY:
			paperNearEmpty.setState(true);
			break;
		case POSPrinterConst.PTR_SUE_REC_PAPEROK:
			paperEmpty.setState(false);
			paperNearEmpty.setState(false);
			break;
		case JposConst.JPOS_SUE_POWER_OFF_OFFLINE:
			offline.setState(true);
			break;
		case JposConst.JPOS_SUE_POWER_ONLINE:
			offline.setState(false);
			break;
		}
	}

	public void outputCompleteOccurred(OutputCompleteEvent e) {
		status.setText("OutputCompleteEvent: " + e.getOutputID());
	}

	public void errorOccurred(ErrorEvent e) {
		status.setText("ErrorEvent: " + e.getErrorCode());
	}
}
